@@ -26,9 +26,6 @@
 #' )
 #'
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_style_1.png}{options: width="500"}}
 style <- function(x, i = NULL, j = NULL,
                   pr_t = NULL, pr_p = NULL, pr_c = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
@@ -90,9 +87,6 @@ style <- function(x, i = NULL, j = NULL,
 #' @examples
 #' ft <- flextable(head(iris))
 #' ft <- bold(ft, bold = TRUE, part = "header")
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_bold_1.png}{options: width="400"}}
 bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "bold()"))
@@ -115,7 +109,7 @@ bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body") {
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(bold) == length(j)) {
+  if (length(bold) == length(j)) {
     bold <- rep(bold, each = length(i))
   }
 
@@ -139,9 +133,6 @@ bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body") {
 #' ft <- fontsize(ft, size = 14, j = 2)
 #' ft <- fontsize(ft, size = 7, j = 3)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_fontsize_1.png}{options: width="400"}}
 fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "fontsize()"))
@@ -179,9 +170,6 @@ fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body") {
 #' @examples
 #' ft <- flextable(head(mtcars))
 #' ft <- italic(ft, italic = TRUE, part = "header")
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_italic_1.png}{options: width="400"}}
 italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "italic()"))
@@ -204,7 +192,7 @@ italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body") {
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(italic) == length(j)) {
+  if (length(italic) == length(j)) {
     italic <- rep(italic, each = length(i))
   }
 
@@ -248,9 +236,6 @@ italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body") {
 #' ft <- highlight(ft, j = "disp", i = ~ disp > 200, color = "yellow")
 #' ft <- highlight(ft, j = ~ drat + wt + qsec, color = my_color_fun)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_highlight_1.png}{options: width="500"}}
 highlight <- function(x, i = NULL, j = NULL, color = "yellow", part = "body", source = j) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "highlight()"))
@@ -281,7 +266,7 @@ highlight <- function(x, i = NULL, j = NULL, color = "yellow", part = "body", so
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(color) == length(j)) {
+  if (length(color) == length(j)) {
     color <- rep(color, each = length(i))
   }
 
@@ -338,11 +323,6 @@ highlight <- function(x, i = NULL, j = NULL, color = "yellow", part = "body", so
 #'   ft_2 <- set_formatter_type(ft_2)
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_color_1.png}{options: width="600"}}
-#'
-#' \if{html}{\figure{fig_color_2.png}{options: width="400"}}
 color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "color()"))
@@ -373,7 +353,7 @@ color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
   i <- get_rows_id(x[[part]], i)
   j <- x$col_keys[get_columns_id(x[[part]], j)]
 
-  if(length(color) == length(j)) {
+  if (length(color) == length(j)) {
     color <- rep(color, each = length(i))
   }
 
@@ -384,12 +364,23 @@ color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
 
 #' @export
 #' @title Set font
-#' @description change font of selected rows and columns of a flextable.
+#' @description Change font of selected rows and columns of a flextable.
+#'
+#' Fonts impact the readability and aesthetics of the table. Font families
+#' refer to a set of typefaces that share common design features, such as 'Arial'
+#' and 'Open Sans'.
+#'
+#' 'Google Fonts' is a popular library of free web fonts that can be
+#' easily integrated in flextable with function [gdtools::register_gfont()].
+#' When output is HTML, the font will be automatically added in the HTML
+#' document.
+#'
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
 #' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
-#' @param fontname single character value. With Word and PowerPoint output, the value specifies the font to
+#' @param fontname single character value, the font family name.
+#' With Word and PowerPoint output, the value specifies the font to
 #' be used to format characters in the Unicode range (U+0000-U+007F).
 #' @param cs.family Optional font to be used to format
 #' characters in a complex script Unicode range. For example, Arabic
@@ -408,7 +399,7 @@ color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
 #' of `fontname`.
 #' @family sugar functions for table style
 #' @examples
-#' require("gdtools")
+#' library(gdtools)
 #' fontname <- "Brush Script MT"
 #'
 #' if (font_family_exists(fontname)) {
@@ -417,11 +408,6 @@ color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
 #'   ft_2 <- font(ft_2, fontname = fontname, j = 5)
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_font_1.png}{options: width="500"}}
-#'
-#' \if{html}{\figure{fig_font_2.png}{options: width="500"}}
 font <- function(x, i = NULL, j = NULL, fontname, part = "body", cs.family = fontname, hansi.family = fontname, eastasia.family = fontname) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "font()"))
@@ -444,16 +430,16 @@ font <- function(x, i = NULL, j = NULL, fontname, part = "body", cs.family = fon
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(fontname) == length(j)) {
+  if (length(fontname) == length(j)) {
     fontname <- rep(fontname, each = length(i))
   }
-  if(length(cs.family) == length(j)) {
+  if (length(cs.family) == length(j)) {
     cs.family <- rep(cs.family, each = length(i))
   }
-  if(length(hansi.family) == length(j)) {
+  if (length(hansi.family) == length(j)) {
     hansi.family <- rep(hansi.family, each = length(i))
   }
-  if(length(eastasia.family) == length(j)) {
+  if (length(eastasia.family) == length(j)) {
     eastasia.family <- rep(eastasia.family, each = length(i))
   }
 
@@ -489,9 +475,6 @@ font <- function(x, i = NULL, j = NULL, fontname, part = "body", cs.family = fon
 #' ft_1 <- padding(ft_1, padding.bottom = 10, part = "header")
 #' ft_1 <- autofit(ft_1)
 #' ft_1
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_padding_1.png}{options: width="400"}}
 padding <- function(x, i = NULL, j = NULL, padding = NULL,
                     padding.top = NULL, padding.bottom = NULL,
                     padding.left = NULL, padding.right = NULL,
@@ -561,16 +544,13 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
 #' ft <- align(ft, align = "right", part = "all")
 #' ft <- theme_tron_legacy(ft)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_align_1.png}{options: width="400"}}
 align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "justify"),
                   part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "align()"))
   }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
-  align_value <- match.arg(align)
+  align_value <- match.arg(align, several.ok = TRUE)
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
@@ -587,7 +567,7 @@ align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "j
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(align_value) == length(j)) {
+  if (length(align_value) == length(j)) {
     align_value <- rep(align_value, each = length(i))
   }
   x[[part]]$styles$pars[i, j, "text.align"] <- align_value
@@ -595,13 +575,38 @@ align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "j
   x
 }
 
-keep_wn <- function(x, i = NULL, j = NULL, keep_with_next = TRUE,
-                    part = "body") {
+#' @export
+#' @title Set Word 'Keep with next' instructions
+#' @description The 'Keep with next' functionality in 'Word', applied
+#' to the rows of a table, ensures that the rows with that attribute
+#' stays together and does not break across multiple pages.
+#'
+#' This function allows much better control of breaks between
+#' pages than the global `keep_with_next` parameter.
+#' @param x a flextable object
+#' @param i rows selection
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
+#' @param value TRUE or FALSE. When applied to a group, all rows
+#' except the last one should be flagged with attribute 'Keep with next'.
+#' @family sugar functions for table style
+#' @seealso [paginate()]
+#' @examples
+#' library(flextable)
+#' dat <- iris[c(1:25, 51:75, 101:125), ]
+#' ft <- qflextable(dat)
+#' ft <- keep_with_next(
+#'   x = ft,
+#'   i = c(1:24, 26:49, 51:74),
+#'   value = TRUE
+#' )
+#'
+#' save_as_docx(ft, path = tempfile(fileext = ".docx"))
+keep_with_next <- function(x, i = NULL, value = TRUE, part = "body") {
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
-      x <- keep_wn(x = x, i = i, j = j, keep_with_next = keep_with_next, part = p)
+      x <- keep_with_next(x = x, i = i, value = value, part = p)
     }
     return(x)
   }
@@ -612,8 +617,7 @@ keep_wn <- function(x, i = NULL, j = NULL, keep_with_next = TRUE,
 
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i)
-  j <- get_columns_id(x[[part]], j)
-  x[[part]]$styles$pars[i, j, "keep_with_next"] <- keep_with_next
+  x[[part]]$styles$pars[i, , "keep_with_next"] <- value
 
   x
 }
@@ -632,11 +636,7 @@ keep_wn <- function(x, i = NULL, j = NULL, keep_with_next = TRUE,
 #' ft <- line_spacing(ft, space = 1.6, part = "all")
 #' ft <- set_table_properties(ft, layout = "autofit")
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_line_spacing_1.png}{options: width="400"}}
 line_spacing <- function(x, i = NULL, j = NULL, space = 1, part = "body") {
-
   if (!inherits(x, "flextable")) stop("align supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
@@ -744,11 +744,6 @@ align_nottext_col <- function(x, align = "right", header = TRUE, footer = TRUE)
 #'   )
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_bg_1.png}{options: width="400"}}
-#'
-#' \if{html}{\figure{fig_bg_2.png}{options: width="300"}}
 bg <- function(x, i = NULL, j = NULL, bg, part = "body", source = j) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "bg()"))
@@ -778,7 +773,7 @@ bg <- function(x, i = NULL, j = NULL, bg, part = "body", source = j) {
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if(length(bg) == length(j)) {
+  if (length(bg) == length(j)) {
     bg <- rep(bg, each = length(i))
   }
 
@@ -802,7 +797,7 @@ data_colors <- function(dataset, fun) {
       stop(msg, call. = FALSE)
     }
   )
-  if(anyNA(out)) {
+  if (anyNA(out)) {
     stop("colors can not contain missing values")
   }
   return(out)
@@ -827,11 +822,6 @@ data_colors <- function(dataset, fun) {
 #'
 #' ft_2 <- valign(ft_1, j = 5, valign = "top", part = "all")
 #' ft_2
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_valign_1.png}{options: width="400"}}
-#'
-#' \if{html}{\figure{fig_valign_2.png}{options: width="400"}}
 valign <- function(x, i = NULL, j = NULL, valign = "center", part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "valign()"))
@@ -860,7 +850,7 @@ valign <- function(x, i = NULL, j = NULL, valign = "center", part = "body") {
 
 
 #' @export
-#' @title rotate cell text
+#' @title Rotate cell text
 #' @description It can be useful to be able to change the direction,
 #' when the table headers are huge for example, header labels can
 #' be rendered as "tbrl" (top to bottom and right to left) corresponding
@@ -931,9 +921,6 @@ valign <- function(x, i = NULL, j = NULL, valign = "center", part = "body") {
 #' ft_2 <- valign(ft_2, i = 3, valign = "bottom")
 #'
 #' ft_2
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_rotate_1.png}{options: width="400"}}
 rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "rotate()"))
@@ -956,7 +943,7 @@ rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body")
   j <- get_columns_id(x[[part]], j)
 
   x[[part]]$styles$cells[i, j, "text.direction"] <- rotation
-  if(!is.null(align)) {
+  if (!is.null(align)) {
     x[[part]]$styles$cells[i, j, "vertical.align"] <- align
   }
 
@@ -968,7 +955,7 @@ rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body")
 # misc. ----
 
 
-#' @title make blank columns as transparent
+#' @title Make blank columns as transparent
 #' @description blank columns are set as transparent. This is a shortcut function
 #' that will delete top and bottom borders, change background color to
 #' transparent, display empty content and set blank columns' width.
@@ -1001,7 +988,6 @@ rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body")
 #' ftab <- width(ftab, j = c(2, 5), width = .1)
 #' ftab
 #' @export
-#' @importFrom officer shortcuts
 empty_blanks <- function(x, width = .05, unit = "in", part = "all") {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "empty_blanks()"))
@@ -1012,7 +998,9 @@ empty_blanks <- function(x, width = .05, unit = "in", part = "all") {
 
   x <- border(x,
     j = x$blanks,
-    border.top = shortcuts$b_null(), border.bottom = shortcuts$b_null(), part = part
+    border.top = fp_border_default(width = 0),
+    border.bottom = fp_border_default(width = 0),
+    part = part
   )
   x <- bg(x, j = x$blanks, bg = "transparent", part = part)
   x <- void(x, j = x$blanks, part = part)
